from django.forms import ModelForm

from .models import Account, Category, Invoice, Snapshot, Transaction


class NummiForm(ModelForm):
    template_name = "main/form/base.html"

    def __init__(self, *args, **kwargs):
        kwargs.pop("user", None)
        super().__init__(*args, **kwargs)


class AccountForm(NummiForm):
    class Meta:
        model = Account
        fields = "__all__"


class CategoryForm(NummiForm):
    class Meta:
        model = Category
        fields = "__all__"


class TransactionForm(NummiForm):
    class Meta:
        model = Transaction
        fields = "__all__"

    def __init__(self, *args, **kwargs):
        _user = kwargs.pop("user")
        super().__init__(*args, **kwargs)
        self.fields["category"].queryset = Category.objects.filter(user=_user)
        self.fields["snapshot"].queryset = Snapshot.objects.filter(user=_user)


class InvoiceForm(NummiForm):
    prefix = "invoice"

    class Meta:
        model = Invoice
        fields = "__all__"


class SnapshotForm(NummiForm):
    class Meta:
        model = Snapshot
        fields = "__all__"

    def __init__(self, *args, **kwargs):
        _user = kwargs.pop("user")
        super().__init__(*args, **kwargs)
        self.fields["account"].queryset = Account.objects.filter(user=_user)
